# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/).

## 0.1.0 - 2019-10-23

Initial release.

### Added

- Add `TracingMiddleware`.
